<?php
/**
 * Authserver, an OAuth2-based single-signon authentication provider written in PHP.
 *
 * Copyright (C) 2017 Lars Vierbergen
 *
 * his program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
namespace vierbergenlars\AuthserverStatsBundle\EventListener;

use App\Entity\User;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use vierbergenlars\AuthserverStatsBundle\Event\StatsEvent;
use Symfony\Bridge\Doctrine\RegistryInterface;
use App\Entity\Group;

class CoreStatsListener implements EventSubscriberInterface
{

    /**
     *
     * @var RegistryInterface
     */
    private $registry;

    public static function getSubscribedEvents()
    {
        return [
            StatsEvent::class => [
                [
                    'getUserStats'
                ],
                [
                    'getGroupStats'
                ]
            ]
        ];
    }

    public function __construct(RegistryInterface $registry)
    {
        $this->registry = $registry;
    }

    public function getUserStats(StatsEvent $event)
    {
        if (!$event->isEnabled('user'))
            return;

        $event->setMuninConfig('user', [
            'graph_title' => 'Authserver users',
            'graph_vlabel' => 'Number of users',
            'graph_category' => 'authserver',
            'enabled.label' => 'Enabled users',
            'enabled.draw' => 'AREA',
            'disabled.label' => 'Disabled users',
            'disabled.draw' => 'AREASTACK'
        ]);

        $queryBuilder = $this->registry->getRepository(User::class)->createQueryBuilder('u');

        /* @var $queryBuilder \Doctrine\ORM\QueryBuilder */

        $queryBuilder->select('count(u)', 'u.enabled')->groupBy('u.enabled');
        $rawStats = $queryBuilder->getQuery()->getArrayResult();
        $stats = [
            'user.enabled' => 0,
            'user.disabled' => 0
        ];
        foreach ($rawStats as $rawStat) {
            if ($rawStat['enabled']) {
                $stats['user.enabled'] += $rawStat['1'];
            } else {
                $stats['user.disabled'] += $rawStat['1'];
            }
        }

        $event->addStatistics($stats);
    }

    public function getGroupStats(StatsEvent $event)
    {
        if (!$event->isEnabled('group'))
            return;

        $event->setMuninConfig('group', [
            'graph_title' => 'Authserver groups',
            'graph_vlabel' => 'Number of groups',
            'graph_category' => 'authserver',
            'count.label' => 'Groups',
            'count.draw' => 'AREA'
        ]);
        $queryBuilder = $this->registry->getRepository(Group::class)->createQueryBuilder('g');

        /* @var $queryBuilder \Doctrine\ORM\QueryBuilder */

        $event->addStatistic('group.count', $queryBuilder->select('count(g)')
            ->getQuery()
            ->getSingleScalarResult());
    }
}